@@ -3,7 +3,7 @@ from docker_registry.core import driver
 from docker_registry.core import exceptions
 from docker_registry.core import lru
 
-import fds
+from fds import GalaxyFDSClient
 
 class Storage(driver.Base):
 
@@ -15,7 +15,7 @@ class Storage(driver.Base):
       self.bucket = config.fds_bucket
       self.accesskey = config.fds_accesskey
       self.secretkey = config.fds_secretkey
-      self.client =  fds.GalaxyFDSClient(self.accesskey, self.secretkey)
+      self.client = GalaxyFDSClient(self.accesskey, self.secretkey)
 
     # Remove the first and last "/" of path for FDS
     def _init_path(self, path=None):
